@@ -1,6 +1,6 @@
 use Yandex::Translate;
 
-my $key = "trnsl.1.1.20170425T124714Z.2bfd03d640900137.1a0c8f628383717958530d14d22bd35814ea2545";
+my $key = "your_yandex_key";
 
 my $tr = Yandex::Translate->new;
 
